@@ -1,5 +1,5 @@
 from .bcolors import bcolors as bc
-from .cache import clear_cache, load_cache, store_cache
+from .cache import clear_cache, load_cache, store_cache,dump_cache_file_to_json
 from .find import idFromName, matchGidByName, get_golden_group_policy, get_network_group_policy,find_rf_profile,find_rf_profile_id_by_name
 from .helpers import aironetie, rfp_pwr, set_aironet_ie, print_update, print_matched,get_golden, rf_profile_pre_proccess,add_valid_channels,get_change_log_from_org,update_change_log,last_change,get_network_last_change_ts
 from .merakiapi import MerakiApi, MerakiAsyncApi
